html{font-family:sans-serif!important}.rti--container{max-width:inherit;--rti-tag:#f63366!important;background-color:#f8f9fa}body{color:#fff;background-color:inherit!important}h3{color:#000;background-color:inherit}button,span{color:#fff}.rti--input{background-color:#f8f9fa}
/*# sourceMappingURL=main.52c07994.chunk.css.map */