self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "8d3369587d69bf2372f0e4ff8d373bac",
    "url": "./index.html"
  },
  {
    "revision": "e1ef8a34caaa35fa23c9",
    "url": "./static/css/main.52c07994.chunk.css"
  },
  {
    "revision": "d2a261fcfe627fb6a1d4",
    "url": "./static/js/2.992b79b8.chunk.js"
  },
  {
    "revision": "9bf7777849ff7c0e7b1f4ddb70e6eb95",
    "url": "./static/js/2.992b79b8.chunk.js.LICENSE.txt"
  },
  {
    "revision": "e1ef8a34caaa35fa23c9",
    "url": "./static/js/main.9931c7b5.chunk.js"
  },
  {
    "revision": "4b3ba0d9c283ff9f3fb6",
    "url": "./static/js/runtime-main.488f8084.js"
  }
]);