(this.webpackJsonpstreamlit_tags=this.webpackJsonpstreamlit_tags||[]).push([[0],{15:function(e,t,a){e.exports=a(25)},23:function(e,t,a){},25:function(e,t,a){"use strict";a.r(t);var n=a(1),r=a.n(n),l=a(9),c=a.n(l),u=a(2),i=a(7),o=a(14),s=(a(23),Object(i.b)((function(e){var t=e.args,a=t.label,l=t.text,c=t.initialValue,s=Object(n.useState)(c),m=Object(u.a)(s,2),E=m[0],b=m[1];return Object(n.useEffect)((function(){return i.a.setFrameHeight()})),r.a.createElement("div",null,r.a.createElement("h3",null,a),r.a.createElement(o.a,{value:E,onChange:function(e){return b(t=e),void i.a.setComponentValue(t);var t},name:a,placeHolder:l}))}))),m=a(12),E=a(13),b=a(30),f=a(26),p=new m.a;c.a.render(r.a.createElement(r.a.StrictMode,null,r.a.createElement(E.a,{value:p},r.a.createElement(b.a,{theme:f.a},r.a.createElement(s,null)))),document.getElementById("root"))}},[[15,1,2]]]);
//# sourceMappingURL=main.9931c7b5.chunk.js.map